@@ -4,4 +4,4 @@ rm -f dist/*.*
 python setup.py bdist_wheel sdist
 twine check dist/*
 read -n 1
-twine upload dist/*
\ No newline at end of file
+twine upload --repository testbench2robotframework dist/*
\ No newline at end of file
