@@ -241,6 +241,19 @@ class Keyword:
         )
 
 
+@dataclass
+class Reference:
+    type: ReferenceType
+    path: str
+
+    @classmethod
+    def from_dict(cls, dictionary):
+        return cls(
+            type=ReferenceType(dictionary.get("type", ReferenceType.Reference)),
+            path=dictionary.get("path", ""),
+        )
+
+
 @dataclass
 class UserReference:
     key: str
@@ -292,7 +305,7 @@ class TestCaseSetSpecificationSummary:
     reviewer: Optional[UserReference]
     udfs: List[UserDefinedField]
     keywords: List[Keyword]
-    references: List[str]
+    references: List[Reference]
     requirements: List[RequirementReference]
     preConditions: List[ConditionSummary]
     postConditions: List[ConditionSummary]
@@ -441,12 +454,12 @@ class TestCaseExecutionDetails:
     actualDuration: int
     currentUser: UserReference
     tester: Optional[UserReference]
-    comments: str
+    comments: str  # TODO: Insert htmlComment
     version: Optional[str]
     defects: List[int]
     udfs: List[UserDefinedField]
     keywords: List[Keyword]
-    references: List[str]
+    references: List[Reference]
 
     @classmethod
     def from_dict(cls, dictionary):
@@ -506,7 +519,7 @@ class InteractionExecutionSummary:
     currentUser: UserReference
     tester: UserReference
     comments: str
-    references: List[str]
+    references: List[Reference]
 
     @classmethod
     def from_dict(cls, dictionary):
@@ -528,7 +541,7 @@ class InteractionSpecificationSummary:
     callType: CallType
     description: str
     comments: str
-    references: List[str]
+    references: List[Reference]
     preConditions: List[ConditionSummary]
     postConditions: List[ConditionSummary]
 
