@@ -5,7 +5,7 @@ from typing import Dict
 from robot.api import ExecutionResult
 
 from .config import Configuration
-from .log import setup_logger, logger
+from .log import logger, setup_logger
 from .result_writer import ResultWriter
 
 
@@ -24,4 +24,6 @@ def robot2testbench(
     logger.debug("Config file loaded.")
     result = ExecutionResult(robot_result_xml)
     logger.debug("Robot framework result xml loaded.")
-    result.visit(ResultWriter(json_input_report, json_output_result, configuration))
+    result.visit(
+        ResultWriter(json_input_report, json_output_result, configuration, robot_result_xml)
+    )
