@@ -4,7 +4,8 @@ import os
 import re
 from dataclasses import dataclass
 from pathlib import Path, PurePath
-from typing import Dict, List, Optional, Set
+from typing import Dict, List, Optional, Set, Tuple
+from uuid import uuid4
 
 from robot.parsing.lexer.tokens import Token
 from robot.parsing.model.blocks import File, SettingSection, TestCase, TestCaseSection
@@ -42,6 +43,9 @@ ROBOT_PATH_SEPARATOR = "/"
 RELATIVE_RESOURCE_INDICATOR = r"^{root}"
 SECTION_SEPARATOR = [EmptyLine.from_params()] * 2
 TESTCASE_SEPARATOR = [EmptyLine.from_params()]
+UNKNOWN_IMPORT_TYPE = str(uuid4())
+LIBRARY_IMPORT_TYPE = str(uuid4())
+RESOURCE_IMPORT_TYPE = str(uuid4())
 
 
 @dataclass
@@ -70,6 +74,8 @@ class RfTestCase:
         self.interaction_calls: List[InteractionCall] = []
         self.used_imports: Dict[str, Set[str]] = {}
         self.config = config
+        self.lib_pattern_list = [re.compile(pattern) for pattern in config.rfLibraryRegex]
+        self.res_pattern_list = [re.compile(pattern) for pattern in config.rfResourceRegex]
         for interaction in test_case_details.interactions:
             self._get_interaction_calls(interaction)
         self.rf_tags = self._get_tags(test_case_details)
@@ -118,16 +124,12 @@ class RfTestCase:
         indent: int,
         interaction: InteractionDetails,
     ):
-        ia_path_parts = interaction.path.split(".")
-        if len(ia_path_parts) == 1:
-            root_subdivision = "UNKNOWN"
-            import_prefix = ia_path_parts[0]
+        resource_type, import_prefix = self._get_keyword_import(interaction)
+
+        if resource_type not in self.used_imports:
+            self.used_imports[resource_type] = {import_prefix}
         else:
-            root_subdivision, import_prefix = ia_path_parts[:2]
-        if root_subdivision not in self.used_imports:
-            self.used_imports[root_subdivision] = {import_prefix}
-        else:
-            self.used_imports[root_subdivision].add(import_prefix)
+            self.used_imports[resource_type].add(import_prefix)
         self.interaction_calls.append(
             AtomicInteractionCall(
                 name=interaction.name,
@@ -138,6 +140,27 @@ class RfTestCase:
             )
         )
 
+    def _get_keyword_import(self, interaction) -> Tuple[str, str]:
+        for pattern in self.lib_pattern_list:
+            match = pattern.search(interaction.path)
+            if match:
+                return LIBRARY_IMPORT_TYPE, match[1].strip()
+        for pattern in self.res_pattern_list:
+            match = pattern.search(interaction.path)
+            if match:
+                return RESOURCE_IMPORT_TYPE, match[1].strip()
+
+        ia_path_parts = interaction.path.split(".")
+        if len(ia_path_parts) == 1:
+            return UNKNOWN_IMPORT_TYPE, ia_path_parts[0]
+        root_subdivision, import_prefix = ia_path_parts[:2]
+        if root_subdivision in self.config.rfLibraryRoots:
+            return LIBRARY_IMPORT_TYPE, import_prefix
+        if root_subdivision in self.config.rfResourceRoots:
+            return RESOURCE_IMPORT_TYPE, import_prefix
+
+        return root_subdivision, import_prefix
+
     def _append_compound_ia_and_analyze_children(
         self,
         cbr_params: Dict[str, str],
@@ -179,7 +202,7 @@ class RfTestCase:
 
     def is_splitting_ia(self, interaction_call, keyword_lists, tc_index):
         return (
-            re.match(
+            re.search(
                 self.config.testCaseSplitPathRegEx,
                 f"{interaction_call.import_prefix}.{interaction_call.name}",
             )
@@ -231,7 +254,7 @@ class RfTestCase:
         return cbr_parameters
 
     def _create_rf_keyword(self, interaction: AtomicInteractionCall) -> KeywordCall:
-        import_prefix = self.config.fullyQualified * f"{interaction.import_prefix}."
+        import_prefix = (self.config.fullyQualified or False) * f"{interaction.import_prefix}."
         interaction_indent = (
             SEPARATOR * interaction.indent if self.config.logCompoundInteractions else SEPARATOR
         )
@@ -390,7 +413,7 @@ class RobotSuiteFileBuilder:
             str(resource)
             for resource_root, resources in import_dict.items()
             for resource in resources
-            if self._is_resource(resource_root)
+            if not self._is_library(resource_root) and self._is_resource(resource_root)
         }
         resources.update(self.config.forcedImport.resources)
         resource_paths = {
@@ -399,7 +422,9 @@ class RobotSuiteFileBuilder:
         return [ResourceImport.from_params(res) for res in sorted(resource_paths)]
 
     def _create_resource_path(self, resource: str) -> str:
-        if not self.config.resourceDirectory:
+        if (
+            not self.config.resourceDirectory
+        ):  # TODO Fehler: Hier springt er raus weil resourceDir nicht gesetzt, sollte aber mindestens das Mapping noch mitnehmen.
             return f"{resource}.resource"
         if not re.match(RELATIVE_RESOURCE_INDICATOR, self.config.resourceDirectory):
             return f"{self.config.resourceDirectory}{ROBOT_PATH_SEPARATOR}{resource}.resource"
@@ -424,15 +449,13 @@ class RobotSuiteFileBuilder:
             root_path,
         ).replace('\\', ROBOT_PATH_SEPARATOR)
 
-    def _is_library(self, root_subdivision: str) -> bool:
-        if root_subdivision in self.config.rfLibraryRoots:
-            return True
-        return False
+    @staticmethod
+    def _is_library(root_subdivision: str) -> bool:
+        return root_subdivision == LIBRARY_IMPORT_TYPE
 
-    def _is_resource(self, root_subdivision: str) -> bool:
-        if root_subdivision in self.config.rfResourceRoots:
-            return True
-        return False
+    @staticmethod
+    def _is_resource(root_subdivision: str) -> bool:
+        return root_subdivision == RESOURCE_IMPORT_TYPE
 
     def _create_rf_library_imports(self, import_dict: Dict[str, Set[str]]) -> List[LibraryImport]:
         libraries = {
@@ -457,8 +480,9 @@ class RobotSuiteFileBuilder:
 
     def _create_rf_unknown_imports(self, import_dict: Dict[str, Set[str]]) -> List[Comment]:
         unknown_imports = {
-            root_subdivision: next(iter(unknown_import))
-            for root_subdivision, unknown_import in import_dict.items()
+            str(unknown_import)
+            for root_subdivision, unknown_imports in import_dict.items()
+            for unknown_import in unknown_imports
             if not self._is_library(root_subdivision) and not self._is_resource(root_subdivision)
         }
         for root, subdivision_names in import_dict.items():
@@ -480,7 +504,6 @@ class RobotSuiteFileBuilder:
 
     def _create_setting_section(self) -> SettingSection:
         subdivisions = self._get_used_subdivisions()
-
         setting_section = SettingSection(header=SectionHeader.from_params(Token.SETTING_HEADER))
         setting_section.body.extend(self._create_rf_variable_imports())
         setting_section.body.extend(self._create_rf_library_imports(subdivisions))
