@@ -155,6 +155,11 @@ def get_directory(json_report_path: Optional[str]) -> str:
     sys.exit("Error opening " + json_report_path + ". File is not a ZIP file.")
 
 
+def ensure_dir_exists(cli_output_dir):
+    if not Path(cli_output_dir).is_dir():
+        Path(cli_output_dir).mkdir(parents=True, exist_ok=True)
+
+
 def replace_invalid_characters(name: str) -> str:
     return re.sub(r'[<>:"/\\|?* ]', "_", name)
 
@@ -168,3 +173,11 @@ def directory_to_zip(directory: Path, new_path: str = None):
         shutil.make_archive(str(new_path), 'zip', str(directory))
     else:
         shutil.make_archive(str(directory), 'zip', str(directory))
+
+
+def get_list_item(liste, index, default: Optional[str]):
+    try:
+        item = liste[index]
+        return item
+    except IndexError:
+        return default
